Class: Rubycc::Doctor::CLI::Row
- Inherits:
-
Struct
- Object
- Struct
- Rubycc::Doctor::CLI::Row
- Defined in:
- lib/rubycc/doctor/cli.rb
Overview
A row of the report: the gem, its resolved status and an optional note.
A row of the report: the gem, its resolved status and an optional note.