Class: Rubycc::Front::AST::Default

Inherits:
Data
  • Object
show all
Defined in:
lib/rubycc/front/ast.rb

Overview

A default: statement label (6.8.1). body is the labeled statement. Like Case it is only meaningful inside a switch, and at most one may appear per switch.

Instance Attribute Summary collapse

Instance Attribute Details

#bodyObject (readonly)

Returns the value of attribute body

Returns:

  • (Object)

    the current value of body



298
299
300
# File 'lib/rubycc/front/ast.rb', line 298

def body
  @body
end

#tokenObject (readonly)

Returns the value of attribute token

Returns:

  • (Object)

    the current value of token



298
299
300
# File 'lib/rubycc/front/ast.rb', line 298

def token
  @token
end