Class: Rubycc::Front::AST::LogicalAnd

Inherits:
Data
  • Object
show all
Defined in:
lib/rubycc/front/ast.rb

Overview

Short-circuit "&&" and "||". Kept apart from Binary because both operands must be int-typed and only one side may end up evaluated at run time, unlike every other Binary operator.

Instance Attribute Summary collapse

Instance Attribute Details

#lhsObject (readonly)

Returns the value of attribute lhs

Returns:

  • (Object)

    the current value of lhs



49
50
51
# File 'lib/rubycc/front/ast.rb', line 49

def lhs
  @lhs
end

#rhsObject (readonly)

Returns the value of attribute rhs

Returns:

  • (Object)

    the current value of rhs



49
50
51
# File 'lib/rubycc/front/ast.rb', line 49

def rhs
  @rhs
end

#tokenObject (readonly)

Returns the value of attribute token

Returns:

  • (Object)

    the current value of token



49
50
51
# File 'lib/rubycc/front/ast.rb', line 49

def token
  @token
end