Class: Rubycc::Link::LibraryResolver::Resolution

Inherits:
Struct
  • Object
show all
Defined in:
lib/rubycc/link/library_resolver.rb

Overview

The outcome of resolving a set of library requests: needed are the shared object paths to bind imports against, inputs the relocatable inputs (archives and objects) to feed the merge, both in first-seen order.

Instance Attribute Summary collapse

Instance Attribute Details

#inputsObject

Returns the value of attribute inputs

Returns:

  • (Object)

    the current value of inputs



139
140
141
# File 'lib/rubycc/link/library_resolver.rb', line 139

def inputs
  @inputs
end

#neededObject

Returns the value of attribute needed

Returns:

  • (Object)

    the current value of needed



139
140
141
# File 'lib/rubycc/link/library_resolver.rb', line 139

def needed
  @needed
end