Class: Rubycc::Link::LibraryResolver::Resolution
- Inherits:
-
Struct
- Object
- Struct
- Rubycc::Link::LibraryResolver::Resolution
- Defined in:
- lib/rubycc/link/library_resolver.rb
Overview
The outcome of resolving a set of library requests: needed are the shared
object paths to bind imports against, inputs the relocatable inputs
(archives and objects) to feed the merge, both in first-seen order.
Instance Attribute Summary collapse
-
#inputs ⇒ Object
Returns the value of attribute inputs.
-
#needed ⇒ Object
Returns the value of attribute needed.
Instance Attribute Details
#inputs ⇒ Object
Returns the value of attribute inputs
139 140 141 |
# File 'lib/rubycc/link/library_resolver.rb', line 139 def inputs @inputs end |
#needed ⇒ Object
Returns the value of attribute needed
139 140 141 |
# File 'lib/rubycc/link/library_resolver.rb', line 139 def needed @needed end |